@@ -1,3 +1,3 @@
 docker build . -t adlinear
-docker tag adlearnhpcprod eu.gcr.io/second-capsule-253207/adlinear:latest
+docker tag adlinear eu.gcr.io/second-capsule-253207/adlinear:latest
 docker push eu.gcr.io/second-capsule-253207/adlinear:latest
\ No newline at end of file
